==> open-xchange-guard-ui_1.0.0.orig.tar.bz2: open-xchange-guard-ui-1.0.0/oxguard-ui/apps/oxguard/crypto/encr.js <==
/* jshint ignore:start */
define('oxguard/crypto/encr', ['oxguard/crypto/jsencrypt', 'io.ox/core/tk/dialogs', 'gettext!oxguard/crypto/encr', 'oxguard/crypto/pkcs5pkey'],
        function (JS, dialogs, gt, pk) {
    'use strict';
    
    var pubkey = '-----BEGIN PUBLIC KEY-----MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEArg0CS7pJpUMrdyreJcsxXxoQf09Lf1RbIdRtUCPPb5YyGddQgYOi+QfRqU1Lr1Hwxf1qs+LVvMZshI9YDF7eejEMlKWc+trvuYyG9GGgZr7wUGVauIdl59JDoaaTuSVc+i2hlild3nSeJg3KfEFxeL9UWCCq3zZXjr09Ve8KVs/Tvg4/mthrOQqIxsBNB36YgBsL6FqGdgA/g/yQeKLQ+b6gVix6/1TNPr4eEFXH1fbUy8vzzOpYKvqkIo3JaXRDFi716m9LkTPNsy0a/nQzZVGCPeTPQ35DiUE3FWlPbbRY06LUQ95KeAbfI8MB0I+xDWa8bGuBAiKinRopCujfAQIDAQAB-----END PUBLIC KEY-----';
    function test(privkey) {
        try {
            var encrypt = new JS.JSEncrypt();
            encrypt.setPublicKey(pubkey);
            var encrypted = encrypt.encrypt('testing');
            var decrypt = new JS.JSEncrypt();
            decrypt.setPrivateKey(privkey);
            var uncrypted = decrypt.decrypt(encrypted);
        } catch (e) {
            
        }
    }
    
    function loadPublicKey(data) {
        try {
            var encrypt = new JS.JSEncrypt();
            encrypt.setPublicKey(data);
            window.oxguarddata.publicKey = encrypt.getPublicKey();
            window.oxguarddata.pubkey64 = data;
            if (encrypt.getPublicKey === null) return false;
            if (encrypt.getPublicKey().indexOf('PUBLIC') > 0) {// verify key loaded
                return true;
            } else {
                alert(gt('Unable to load'));
                return false;
            }
        } catch (e) {
            console.log(e);
            alert(gt('Unable to load'));
            return false;
        }
        
    }
    

    function decodeKey(key, password) {

        try {
            var privKey = '';
            if (key.indexOf('BEGIN ENCRYPTED PRIVATE KEY') > 0) { //pkcs8 vs 5
                privKey = pk.PKCS5PKEY.getPlainPKCS8HexFromEncryptedPKCS8PEM(key, password);
            } else {
                privKey = pk.PKCS5PKEY.getDecryptedKeyHex(key, password.trim());
            }
            return (privKey);
        } catch (e) {
            console.log(e);
        }
            
    }
    
    function createForm(location) {
        var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter : 'ok'});
        dialog.header($('<h4>').text(gt('Need Private Key')));
        var info = $('<p>' + gt('Please select the file location of your private key.') + '<br/>' + gt('The key will be used locally only.  It will not be sent to the server.') + '</p>');
        var password = $('<label>' + gt('Private Key Password') + '</label><input type="password" id="priv_pass"/></br>');
        info.append(password);
        var btn = $('<button class="btn og_getkey">' + gt('Select Key Location') + '</button>');

        var input = $('<input type="file" id="files" name="files[] style="padding:10px;visibility:hidden;position:absolute;top-50px;left:-50px;"/>');
        btn.click(function () {
            input.click();
        });
        input.change(function (evt) {
            var file = evt.target.files[0];
            var reader = new FileReader();

            reader.onload = function (event) {
                var data = event.target.result;
                var privkey = decodeKey(data, $('#priv_pass').val());
                test(privkey);
                dialog.close();
            };
            reader.readAsText(file);

            
        });
        btn.after(input);
        dialog.getBody().append(info.append(btn));
        dialog
        .addButton('cancel', gt('Cancel'), 'cancel');
        dialog.show();
    }
    

    return {
        test : test,
        createForm : createForm,
        decodeKey : decodeKey,
        loadPublicKey : loadPublicKey
    };
});
/* jshint ignore:end */

==> open-xchange-guard-ui_2.0.0.orig.tar.bz2: open-xchange-guard-ui-2.0.0/oxguard-ui/apps/oxguard/crypto/encr.js <==
/* jshint ignore:start */
define('oxguard/crypto/encr', ['oxguard/crypto/jsencrypt'],
        function (JS) {
    'use strict';
    
    function test(privkey) {
        try {
            var encrypt = new JS.JSEncrypt();
            encrypt.setPublicKey(pubkey);
            var encrypted = encrypt.encrypt('testing');
            var decrypt = new JS.JSEncrypt();
            decrypt.setPrivateKey(privkey);
            var uncrypted = decrypt.decrypt(encrypted);
        } catch (e) {
            
        }
    }
    
    function loadPublicKey(data) {
        try {
            var encrypt = new JS.JSEncrypt();
            encrypt.setPublicKey(data);
            window.oxguarddata.publicKey = encrypt.getPublicKey();
            window.oxguarddata.pubkey64 = data;
            if (encrypt.getPublicKey === null) return false;
            if (encrypt.getPublicKey().indexOf('PUBLIC') > 0) {// verify key loaded
                return true;
            } else {
                alert(gt('Unable to load'));
                return false;
            }
        } catch (e) {
            console.log(e);
            alert(gt('Unable to load'));
            return false;
        }
        
    }
    
    function getEncrypted(pubKey, data) {
        try {
            if (pubKey === null) return(null);
            var encrypt = new JS.JSEncrypt();
            encrypt.setPublicKey(pubKey);
            if (encrypt.getPublicKey().indexOf('PUBLIC') < 0) {
                console.log('pubkey import fail');
                return (null);
            }
            var encrypted = encrypt.encrypt(data);
            return(encrypted);
        } catch (e) {
            console.log(e);
            return(null);
        }
    }
    
    function cryptPass (password) {
        if (window.oxguarddata.pubkey === undefined) return(null);
        return (getEncrypted (window.oxguarddata.pubkey, password));
    }
    
/*
    function decodeKey(key, password) {

        try {
            var privKey = '';
            if (key.indexOf('BEGIN ENCRYPTED PRIVATE KEY') > 0) { //pkcs8 vs 5
                privKey = pk.PKCS5PKEY.getPlainPKCS8HexFromEncryptedPKCS8PEM(key, password);
            } else {
                privKey = pk.PKCS5PKEY.getDecryptedKeyHex(key, password.trim());
            }
            return (privKey);
        } catch (e) {
            console.log(e);
        }
            
    }

    function createForm(location) {
        var dialog = new dialogs.CreateDialog({ width: 450, center: true,  enter : 'ok'});
        dialog.header($('<h4>').text(gt('Need Private Key')));
        var info = $('<p>' + gt('Please select the file location of your private key.') + '<br/>' + gt('The key will be used locally only.  It will not be sent to the server.') + '</p>');
        var password = $('<label>' + gt('Private Key Password') + '</label><input type="password" id="priv_pass"/></br>');
        info.append(password);
        var btn = $('<button class="btn og_getkey">' + gt('Select Key Location') + '</button>');

        var input = $('<input type="file" id="files" name="files[] style="padding:10px;visibility:hidden;position:absolute;top-50px;left:-50px;"/>');
        btn.click(function () {
            input.click();
        });
        input.change(function (evt) {
            var file = evt.target.files[0];
            var reader = new FileReader();

            reader.onload = function (event) {
                var data = event.target.result;
                var privkey = decodeKey(data, $('#priv_pass').val());
                test(privkey);
                dialog.close();
            };
            reader.readAsText(file);

            
        });
        btn.after(input);
        dialog.getBody().append(info.append(btn));
        dialog
        .addButton('cancel', gt('Cancel'), 'cancel');
        dialog.show();
    }
    */

    return {
        test : test,
  //      createForm : createForm,
  //      decodeKey : decodeKey,
        loadPublicKey : loadPublicKey,
        getEncrypted : getEncrypted,
        cryptPass : cryptPass
    };
});
/* jshint ignore:end */
